# Contributor Covenant Code of Conduct

## Our Pledge

We as members, contributors, and leaders pledge to make participation in our
community a harassment-free experience for everyone, regardless of age, body
size, visible or invisible disability, ethnicity, sex characteristics, gender
identity and expression, level of experience, education, socio-economic status,
nationality, personal appearance, race, religion, or sexual identity
and orientation.

## Our Standards

Examples of behavior that contributes to a positive environment:

* Demonstrating empathy and kindness toward other people
* Being respectful of differing opinions, viewpoints, and experiences
* Giving and gracefully accepting constructive feedback
* Accepting responsibility for mistakes and learning from them
* Focusing on what is best for the overall community

Examples of unacceptable behavior:

* Harassment, trolling, or personal attacks
* Publishing others private information without permission
* Other conduct which could reasonably be considered inappropriate

## Enforcement

Community leaders are responsible for clarifying and enforcing our standards.

## Attribution

This Code of Conduct is adapted from the Contributor Covenant, version 2.0.
